{{/* vim: set filetype=mustache: */}}
{{/* Expand the name of the chart. */}}
{{- define "cnc.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/* Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name. */}}
{{- define "cnc.fullname" -}}
{{- if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}

{{/* Create chart name and version as used by the chart label. */}}
{{- define "cnc.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/* Common labels */}}
{{- define "chart.labels" -}}
app.kubernetes.io/name: {{ include "cnc.name" . }}
helm.sh/chart: {{ include "cnc.chart" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: "{{ include "cnc.app-version" . }}"
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
chart: {{ .Chart.Name | quote }}
{{- end -}}

{{- define "service.labels" -}}
helm.sh/chart: {{ include "cnc.chart" . }}
{{ include "service.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: "{{ include "cnc.app-version" . }}"
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{- define "service.selectorLabels" -}}
app.kubernetes.io/name: {{ .serviceName }}
app.kubernetes.io/instance: {{ .Release.Name }}
app.kubernetes.io/component: {{ .serviceName }}
app.kubernetes.io/part-of: coverity
{{- end }}

{{- define "cim.common.selectorLabels" -}}
app.kubernetes.io/name: {{ .serviceName }}
app.kubernetes.io/instance: {{ .Release.Name }}
app.kubernetes.io/component: cim
app.kubernetes.io/part-of: coverity
{{- end }}

{{- define "jgroups.service.selectorLabels" -}}
app.kubernetes.io/component: cim
{{- end }}

{{- define "jgroups.service.url" -}}
- name: JGROUPS_DNS_QUERY
  value: {{ include "cnc.fullname" . }}-cim-jgroups-svc.{{ .Release.Namespace }}.svc.cluster.local
{{- end }}

{{- define "cnc.app-version" -}}
{{- printf "%s" .Chart.AppVersion | replace "+" "_" | replace ":" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
https://github.com/openstack/openstack-helm-infra/blob/master/helm-toolkit/templates/utils/_joinListWithComma.tpl
*/}}
{{- define "helm-toolkit.utils.joinListWithComma" -}}
{{- $local := dict "first" true -}}
{{- range $k, $v := . -}}{{- if not $local.first -}},{{- end -}}{{- $v -}}{{- $_ := set $local "first" false -}}{{- end -}}
{{- end -}}

{{- define "cnc.image.name" -}}
    {{ printf "%s/%s:%s%s" (default .Values.imageRegistry (index .Values .serviceName).registry) (required "missing image name" (index .Values .serviceName).image) (default .Values.imageVersion (index .Values .serviceName).version) (.Values.imageTagSuffix) | quote }}
{{- end }}


{{- define "cnc.postgres.secret" }}
{{- if not (or .Values.postgres.existingSecret (index .Values .serviceName).postgres.existingSecret) }}
apiVersion: v1
kind: Secret
metadata:
  name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
  namespace: {{ .Release.Namespace }}
  annotations:
    helm.sh/hook-weight: "-14"
    helm.sh/hook: pre-upgrade, pre-install
type: Opaque
stringData:
  host: {{ (index .Values .serviceName).postgres.host | default .Values.postgres.host | quote }}
  port: {{ (index .Values .serviceName).postgres.port | default .Values.postgres.port | quote }}
  username: {{ (index .Values .serviceName).postgres.user | default .Values.postgres.user | quote }}
  password: {{ (index .Values .serviceName).postgres.password | default .Values.postgres.password | quote }}
{{- end }}
{{- end }}

{{- define "cnc.cim.postgres.jdbcurl" -}}
jdbc:postgresql://${POSTGRES_HOST}:${POSTGRES_PORT}/${POSTGRES_DATABASE}?sslmode={{ (index .Values "cim").postgres.sslmode | default .Values.postgres.sslmode }}&sslfactory=org.postgresql.ssl.DefaultJavaSSLFactory
{{- end -}}

{{- define "cnc.postgres.environment" }}
{{- if or .Values.postgres.existingSecret (index .Values .serviceName).postgres.existingSecret }}
- name: POSTGRES_HOST
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).postgres.existingSecret | default .Values.postgres.existingSecret | quote }}
      key: "host"
- name: POSTGRES_PORT
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).postgres.existingSecret | default .Values.postgres.existingSecret | quote }}
      key: "port"
- name: POSTGRES_USERNAME
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).postgres.existingSecret | default .Values.postgres.existingSecret | quote }}
      key: "username"
- name: POSTGRES_PASSWORD
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values .serviceName).postgres.existingSecret | default .Values.postgres.existingSecret | quote }}
      key: "password"
{{- else }}
- name: POSTGRES_HOST
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "host"
- name: POSTGRES_PORT
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "port"
- name: POSTGRES_USERNAME
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "username"
- name: POSTGRES_PASSWORD
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
      key: "password"
{{- end }}
- name: POSTGRES_DATABASE
  value: {{ (index .Values .serviceName).postgres.database | quote }}
{{- end }}


{{- define "cim.contextPath" -}}
{{- if .Values.cim.cimweb.contextPath -}}
{{- .Values.cim.cimweb.contextPath -}}/
{{- else -}}
{{- end -}}
{{- end -}}

{{/*
securityContext for the scanfarm pod level.
*/}}
{{- define "cnc.scanfarm.securityContext.pod" }}
  {{- if (index .Values .serviceName).podSecurityContext }}
      {{- with (index .Values .serviceName).podSecurityContext }}
      securityContext:
        {{- toYaml . | nindent 8 }}
      {{- end }}
  {{- else }}
      securityContext:
        runAsNonRoot: true
        {{- if .Capabilities.APIVersions.Has "security.openshift.io/v1" }}
        {{- else }}
        runAsUser: 5000
        {{- end }}
  {{- end }}
{{- end }}

{{/*
securityContext for the cim pod level.
*/}}
{{- define "cnc.cim.securityContext.pod" }}
  {{- if .Values.cim.podSecurityContext }}
      {{- with .Values.cim.podSecurityContext }}
      securityContext:
        {{- toYaml . | nindent 8 }}
      {{- end }}
  {{- else }}
      securityContext:
        runAsNonRoot: true
        {{- if .Capabilities.APIVersions.Has "security.openshift.io/v1" }}
        {{- else }}
        runAsUser: 5000
        {{- end }}
  {{- end }}
{{- end }}

{{- define "generateTLShosts" -}}
  {{- $protocol := "" }}
  {{- if (index .Values "cim").ingress.tls }}
    {{- $protocol = "https://" }}
  {{- else }}
    {{- $protocol = "http://" }}
  {{- end }}
  {{- $hosts := "" }}
  {{- range $host := (index .Values "cim").ingress.hosts -}}
    {{- $hosts = printf "%s%s%s " $hosts $protocol $host -}}
  {{- end -}}
  {{- $hosts |trimSuffix " " | splitList " " | join "," }}
{{- end }}

{{/* vim: set filetype=mustache: */}}
{{/*
Renders a value that contains template.
Usage:
{{ include "common.tplvalues.render" ( dict "value" .Values.path.to.the.Value "context" $) }}
*/}}
{{- define "common.tplvalues.render" -}}
    {{- if typeIs "string" .value }}
        {{- tpl .value .context }}
    {{- else }}
        {{- tpl (.value | toYaml) .context }}
    {{- end }}
{{- end -}}

{{/*
Check if Kubernetes version is 1.28 or greater and return true or false.
Usage: {{- if isKubeVersionValid .Capabilities.KubeVersion.GitVersion }} ... {{- end }}
*/}}
{{- define "isKubeVersionValid" -}}
{{- $kubeMajorVersion := .Capabilities.KubeVersion.Major | int  }}
{{- $kubeMinorVersion := .Capabilities.KubeVersion.Minor | int }}
{{- if and (ge $kubeMajorVersion 1) (ge $kubeMinorVersion 28) }}
true
{{- end }}
{{- end }}

{{/*
it will generate a secret with random string.
*/}}
{{- define "cnc.scanimpersonation.secret" }}
{{- $secretName := include "cnc.fullname" . -}}
{{- $tokenSecretName := printf "%s-impersonation-token" $secretName -}}
{{- $existingSecret := lookup "v1" "Secret" .Release.Namespace $tokenSecretName | default "" -}}
{{- $existingSecretStr := toString $existingSecret -}}
{{- if eq $existingSecretStr "" -}}
apiVersion: v1
kind: Secret
metadata:
  name: {{ include "cnc.fullname" . }}-impersonation-token
  namespace: {{ .Release.Namespace }}
  annotations:
    helm.sh/hook-weight: "-9"
    helm.sh/hook:  pre-upgrade, pre-install
type: Opaque
stringData:
  token:  "{{- randAlphaNum 16 | nospace -}}"
{{- end }}
{{- end }}

{{/* Commit rcp4 */}}

{{- define "commitrcp4.image.name" -}}
    {{ printf "%s/%s:%s%s" (default .Values.imageRegistry (index .Values.cim.commitrcp4 .serviceName).registry) (required "missing image name" (index .Values.cim.commitrcp4 .serviceName).image) (default .Values.imageVersion (index .Values.cim.commitrcp4 .serviceName).version) (.Values.imageTagSuffix) | quote }}
{{- end }}


{{- define "commitrcp4.postgres.secret" }}
apiVersion: v1
kind: Secret
metadata:
  name: {{ include "cnc.fullname" . }}-{{ .serviceName }}-db-creds
  namespace: {{ .Release.Namespace }}
  annotations:
    helm.sh/hook-weight: "-14"
    helm.sh/hook: pre-upgrade, pre-install
type: Opaque
stringData:
  host: {{ .Values.cim.postgres.host | default .Values.postgres.host | quote }}
  port: {{ .Values.cim.postgres.port | default .Values.postgres.port | quote }}
  username: {{ .Values.cim.postgres.user | default .Values.postgres.user | quote }}
  password: {{ .Values.cim.postgres.password | default .Values.postgres.password | quote }}
  database: {{ .Values.cim.postgres.database | default .Values.cim.postgres.database | quote }}
{{- end }}

{{- define "commitrcp4.postgres.jdbcurl" -}}
jdbc:postgresql://{{ .Values.cim.postgres.host | default .Values.postgres.host }}:{{ .Values.cim.postgres.port | default .Values.postgres.port }}/{{ .Values.cim.postgres.database }}?sslmode={{ (index .Values.cim.commitrcp4 "cnc-server-worker").postgres.sslmode | default .Values.postgres.sslmode }}&sslfactory=org.postgresql.ssl.DefaultJavaSSLFactory
{{- end }}

{{- define "commitrcp4.redis.volumemount" }}
{{- if or .Values.cim.commitrcp4.redis.cacertSecret (index .Values "cnc-cache-service").redis.cacertSecret }}
- name: redis-certs
  mountPath: /etc/redis/ssl
{{- end}}
{{- end }}

{{- define "commitrcp4.redis.volume" }}
{{- if or .Values.cim.commitrcp4.redis.cacertSecret (index .Values "cnc-cache-service").redis.cacertSecret }}
- name: redis-certs
  secret:
    defaultMode: 420
    secretName: {{ .Values.cim.commitrcp4.redis.cacertSecret | default (index .Values "cnc-cache-service").redis.cacertSecret }}
{{- end}}
{{- end }}

{{- define "commitrcp4.redis.environment" }}
- name: REDIS_HOST
  value: {{ required "missing redis host" ( .Values.cim.commitrcp4.redis.host | default (index .Values "cnc-cache-service").redis.host ) | quote }}
- name: REDIS_PORT
  value: {{ required "missing redis port" ( .Values.cim.commitrcp4.redis.port | default (index .Values "cnc-cache-service").redis.port ) | quote }}
- name: REDIS_DATABASE
  value: {{ required "missing redis database" ( .Values.cim.commitrcp4.redis.database ) | quote }}
- name: REDIS_PASSWORD
  {{- if or .Values.cim.commitrcp4.redis.authEnabled (index .Values "cnc-cache-service").redis.authEnabled }}
  valueFrom:
    secretKeyRef:
      name: {{ required "missing redis passwordSecret" ( .Values.cim.commitrcp4.redis.passwordSecret | default (index .Values "cnc-cache-service").redis.passwordSecret ) | quote }}
      key: password
      optional: false
  {{- else }}
  value: ""
  {{- end}}
- name: REDIS_SECURE
  value: {{ required "missing redis secure" ( .Values.cim.commitrcp4.redis.secure | default (index .Values "cnc-cache-service").redis.secure ) | quote }}
- name: REDIS_CACERT
  {{- if or .Values.cim.commitrcp4.redis.cacertSecret (index .Values "cnc-cache-service").redis.cacertSecret }}
  value: /etc/redis/ssl/ca.crt
  {{- else }}
  value: ""
  {{- end}}
- name: REDIS_VERIFY_HOSTNAME
  value: {{ required "missing redis verifyHostName" ( .Values.cim.commitrcp4.redis.verifyHostName | default (index .Values "cnc-cache-service").redis.verifyHostName ) | quote }}
{{- end }}

{{- define "commitrcp4.storage.secret" }}
{{- if not (index .Values.cim.commitrcp4 "cnc-storage-proxy").secret.name }}
apiVersion: v1
kind: Secret
metadata:
  name: {{ include "cnc.fullname" . }}-storage-secret
  namespace: {{ .Release.Namespace }}
  annotations:
    helm.sh/hook-weight: "-14"
    helm.sh/hook: pre-upgrade, pre-install
type: Opaque
stringData:
  access_key: {{ required "missing access key" (index .Values.cim.commitrcp4 "cnc-storage-proxy").accessKey | quote }}
  secret_key: {{ required "missing secret key" (index .Values.cim.commitrcp4 "cnc-storage-proxy").secretKey | quote }}
{{- end }}
{{- end }}

{{- define "commitrcp4.storage.environment" }}
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_PROVIDER
  value: {{ (index .Values.cim.commitrcp4 "cnc-storage-proxy").storageType | quote }}
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_ENDPOINT
  value: {{ (index .Values.cim.commitrcp4 "cnc-storage-proxy").endpoint | quote }}
{{- if not (index .Values.cim.commitrcp4 "cnc-storage-proxy").secret.name }}
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_ACCESSKEY
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-storage-secret
      key: "access_key"
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_SECRETKEY
  valueFrom:
    secretKeyRef:
      name: {{ include "cnc.fullname" . }}-storage-secret
      key: "secret_key"
{{- else }}
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_ACCESSKEY
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values.cim.commitrcp4 "cnc-storage-proxy").secret.name }}
      key: "access_key"
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_SECRETKEY
  valueFrom:
    secretKeyRef:
      name: {{ (index .Values.cim.commitrcp4 "cnc-storage-proxy").secret.name }}
      key: "secret_key"
{{- end }}
- name: COM_SYNOPSYS_COVERITY_COMMIT_BLOB_REGION
  value: {{ required "missing region" (index .Values.cim.commitrcp4 "cnc-storage-proxy").region | quote }}
{{- end }}

{{- define "commitrcp4.common.temporal.environment" }}
- name: TEMPORAL_HOSTPORT
  value: {{ include "cnc.fullname" . }}-cnc-temporal-service:7233
- name: TEMPORAL_NAMESPACE
  value: "server"
- name: TEMPORAL_WORKFLOWRETENTIONINDAYS
  value: "1"
- name: TEMPORAL_EXPIRATIONTIMEOUTINSECONDS
  value: "60"
- name: TEMPORAL_POLLINTERVALINSECONDS
  value: "1"
- name: TEMPORAL_POLLTHREADCOUNT
  value: "30"
{{- end }}